@@ -2,19 +2,22 @@ package App::Hachero::Plugin::Parse::HadoopReduce;
 use strict;
 use warnings;
 use base 'App::Hachero::Plugin::Base';
-use App::Hachero::Result;
+use UNIVERSAL::require;
 
 sub parse : Hook {
     my ( $self, $context, $args ) = @_;
     my ($key, $value) = split(/\t/,$context->currentline);
     my $VAR1; # for Data::Dumper;
     eval $value;
+    (my $package = ref $VAR1) =~ s/::Result//;
+    $package->require;
     my ($prime, $second) = split('-',$key);
-    my $record = $context->result->{$prime}->{$second};
-    if ($record) {
-        $record->count_up($VAR1->{count});
+    my $result = $context->result->{$prime};
+    if ($result) {
+        my ($value) = $VAR1->values;
+        $result->push($value->hashref);
     } else {
-        $context->result->{$prime}->{$second} = $VAR1;
+        $context->result->{$prime} = $VAR1;
     }
 }
 
